/*
 * libsgml -- SGML state machine parsing library.
 *                                                                  
 * Copyright (c) 2002 Uninformed Research (http://www.uninformed.org)
 * All rights reserved.
 *
 * skape
 * mmiller@hick.org
 */
/**
 * @defgroup DOMElement Element
 * @ingroup  DOMNode
 *
 * Element node manipulation.
 *
 * @{
 */
#ifndef _LIBSGML_DOMELEMENT_H
#define _LIBSGML_DOMELEMENT_H

#include "DomNode.h"

/**
 * @def DOM_ELEMENT
 *
 * Defines a DOM_ELEMENT as a DOM_NODE.  This gives us "inheritance" in C.
 */
#define DOM_ELEMENT DOM_NODE

/**
 * Constructs a DOM element with the given name.
 *
 * @param  name [in] The name of the element to construct.
 * @return The initialize DOM element node.
 */
DOM_ELEMENT *domElementNew(const char *name);
/**
 * Recursively destroys a DOM element.
 *
 * @param  element [in] The element to be destroyed.
 */
void domElementDestroy(DOM_ELEMENT *element);

/**
 * Sets an attribute on an element by its name.
 *
 * @param  element [in] The element node to set the attribute on.
 * @param  name    [in] The name of the attribute.
 * @param  value   [in] The value of the attribute.
 */
void domElementSetAttribute(DOM_ELEMENT *element, const char *name, const char *value);
/**
 * Unsets an attribute on an element by its name.
 *
 * @param  element [in] The element node to unset the attribute on.
 * @param  name    [in] The name of the attribute.
 */
void domElementUnsetAttribute(DOM_ELEMENT *element, const char *name);

/**
 * Get the value associated with an attribute by its name.
 *
 * @param  element [in] The element node to set the attribute on.
 * @param  name    [in] The name of the attribute.
 * @return On success, a valid pointer is return that is the value associated with the attribute 'name'.  Otherwise, NULL is returned.
 */
const char *domElementGetAttribute(DOM_ELEMENT *element, const char *name);

/**
 * @}
 */

#endif
